@@ -74,22 +74,24 @@ class Wimby:
                     while len(fmovement) < padding:
                         fmovement = f" {fmovement}"
                     
-                    if change == 0:
-                        print(f"{fmovement} {token}")
-                    else:
-                        print(f"{fmovement} {token} ({change:,.2f}%)")
+                    print(f"{token}")
                     pattern = self.momentum.get(token, {}).get("trend", "")
                     buy_score = self.momentum.get(token, {}).get("buy", 0) * 100
                     sell_score = self.momentum.get(token, {}).get("sell", 0) * 100
                     hold_score = max((buy_score, sell_score))
                     if pattern.strip() != "":
                         print(f"    {pattern}")
+                    if change == 0:
+                        print(f"    Movement: {fmovement}")
+                    else:
+                        print(f"    Movement: {fmovement} ({change:,.2f}%)")
+                    if not max((hold_score, buy_score, sell_score)) == 0:
                         if hold_score <= 60:
                             print(f"    HOLD: {hold_score:,.2f}%")
                         elif buy_score > sell_score:
-                            print(f"    BUY:  {buy_score:,.2f}%")
+                                print(f"    BUY:  {buy_score:,.2f}%")
                         else:
-                            print(f"    SELL: {sell_score:,.2f}%")
+                                print(f"    SELL: {sell_score:,.2f}%")
             trend_avg = mean(market_trend)
             trend_mode = mode(market_trend)
             print("\n[Market Trends]")
